==> engine-3.2.0-sources.jar: org/opencds/cqf/cql/engine/elm/executing/PopulationStdDevEvaluator.java <==
package org.opencds.cqf.cql.engine.elm.executing;

import org.opencds.cqf.cql.engine.exception.InvalidOperatorArgument;
import org.opencds.cqf.cql.engine.execution.State;
import org.opencds.cqf.cql.engine.runtime.Quantity;

import java.math.BigDecimal;
import java.util.List;

/*
PopulationStdDev(argument List<Decimal>) Decimal
PopulationStdDev(argument List<Quantity>) Quantity

The PopulationStdDev operator returns the statistical standard deviation of the elements in source.
If the source contains no non-null elements, null is returned.
If the source is null, the result is null.
Return types: BigDecimal & Quantity
*/

public class PopulationStdDevEvaluator {

    public static Object popStdDev(Object source, State state) {

        if (source == null) {
            return null;
        }

        if (source instanceof Iterable) {

            if (((List<?>) source).isEmpty()) {
                return null;
            }

            Object variance = PopulationVarianceEvaluator.popVariance(source, state);

            return variance instanceof BigDecimal ?
                    PowerEvaluator.power(variance, new BigDecimal("0.5")) :
                    new Quantity().withValue((BigDecimal) PowerEvaluator.power(((Quantity) variance).getValue(),
                            new BigDecimal("0.5"))).withUnit(((Quantity) variance).getUnit());
        }

        throw new InvalidOperatorArgument(
                "PopulationStdDev(List<Decimal>) or PopulationStdDev(List<Quantity>)",
                String.format("PopulationStdDev(%s)", source.getClass().getName())
        );
    }

}

==> engine-3.9.0-sources.jar: org/opencds/cqf/cql/engine/elm/executing/PopulationStdDevEvaluator.java <==
package org.opencds.cqf.cql.engine.elm.executing;

import java.math.BigDecimal;
import java.util.List;
import org.opencds.cqf.cql.engine.exception.InvalidOperatorArgument;
import org.opencds.cqf.cql.engine.execution.State;
import org.opencds.cqf.cql.engine.runtime.Quantity;

/*
PopulationStdDev(argument List<Decimal>) Decimal
PopulationStdDev(argument List<Quantity>) Quantity

The PopulationStdDev operator returns the statistical standard deviation of the elements in source.
If the source contains no non-null elements, null is returned.
If the source is null, the result is null.
Return types: BigDecimal & Quantity
*/

public class PopulationStdDevEvaluator {

    public static Object popStdDev(Object source, State state) {

        if (source == null) {
            return null;
        }

        if (source instanceof Iterable) {

            if (((List<?>) source).isEmpty()) {
                return null;
            }

            Object variance = PopulationVarianceEvaluator.popVariance(source, state);

            return variance instanceof BigDecimal
                    ? PowerEvaluator.power(variance, new BigDecimal("0.5"))
                    : new Quantity()
                            .withValue((BigDecimal)
                                    PowerEvaluator.power(((Quantity) variance).getValue(), new BigDecimal("0.5")))
                            .withUnit(((Quantity) variance).getUnit());
        }

        throw new InvalidOperatorArgument(
                "PopulationStdDev(List<Decimal>) or PopulationStdDev(List<Quantity>)",
                String.format("PopulationStdDev(%s)", source.getClass().getName()));
    }
}
